@@ -71,10 +71,8 @@
 #define HAVE_SYMLINK 1
 #define HAVE_READLINK 1
 #define HAVE_SETITIMER 1
-#define HAVE_SETRUID 1
 #define HAVE_SETEUID 1
 #define HAVE_SETREUID 1
-#define HAVE_SETRGID 1
 #define HAVE_SETEGID 1
 #define HAVE_SETREGID 1
 #define HAVE_PAUSE 1
@@ -93,16 +91,19 @@
 #define HAVE_TELLDIR 1
 #define HAVE_SEEKDIR 1
 #define HAVE_FCHMOD 1
+#define HAVE_INITSTATE 1
 #define HAVE_TM_ZONE 1
+#define HAVE_STRUCT_TM_TM_GMTOFF 1
 #define POSIX_SIGNAL 1
 #define GETPGRP_VOID 1
 #define RSHIFT(x,y) ((x)>>(int)y)
 #define FILE_COUNT _r
 #define DEFAULT_KCODE KCODE_NONE
+#define USE_ELF 1
 #define DLEXT ".so"
 #define RUBY_LIB "/usr/local/lib/ruby/1.6"
 #define RUBY_SITE_LIB "/usr/local/lib/ruby/site_ruby"
 #define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.6"
-#define RUBY_PLATFORM "i386-openbsd2.9"
-#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.6/i386-openbsd2.9"
-#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.6/i386-openbsd2.9"
+#define RUBY_PLATFORM "i386-openbsd3.4"
+#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.6/i386-openbsd3.4"
+#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.6/i386-openbsd3.4"
